%
% Purpose: check whether even harmonics of current increase strongly with
%  the presence of a battery (even harmonics indicate a non-symmetric
%   waveform, whereas odd harmonics alone indicate a non-sinusoidal but
%   symmetric +/- waveform)
%
% See 'ABOUT' file for more waffle.
%

D = '../rawdata_idf_files';
F = {
    '31_ppcap220nF.idf'   % no batt
    '33_ppcap220nF_+100Vdc.idf'  % alkaline, +
    '34_ppcap220nF_-100Vdc.idf'  % alkaline, -
    '36_ppcap220nF_+100Vdc_Li.idf'  % lithium, +
    '37_ppcap220nF_-100Vdc_Li-2.idf'  % lithium, -
    };


for h = [2,3,4,5]  % harmonic orders to plot
    
    figure(h);
    %close(1); figure(1); hold off;
    subplot(1,1,1); hold off;
    legs = {};
    
    for n=1:numel(F),
        
        fn = fullfile(D,F{n});  % file name to open
        % make a nice name for legend/etc
        fn_txt = regexprep( regexprep(F{n}, '.*nF_?(.*dc)?_?(Li)?(-2)?\.idf', '$1 $2'), 'dc $', ' Alk' );
        if strcmp(fn_txt,' '); fn_txt = 'no battery'; end
        
        %[ harmonics, points, freq, voltage(complex), current(complex), blah,blah ] = ...
        %  for 'v' and 'i' each measurement point gives 8 complex values which
        %  are the fourier components 1:8; they use the same reference angle
        %  between v and i (rather important!) but the absolute angle has no
        %  promised special meaning
        [Nh, Np, f, v, i, ampspec, blurb] = ida_read_idf(fn);
        legs = [ legs, {fn_txt} ];
        
        semilogx( f, abs( i(:,h)./i(:,1) ), '.-' );
        hold on;
        
    end
    
    hold off;
    legend( legs );
    xlabel('$f$ / Hz');
    ylabel(sprintf('harmonic-%d relative current: $\\left|i_{(h=%d)}\\right| / \\left|i_{(h=1)}\\right|$',h,h));
    
end


