% plot frequency-domain spectroscopy results from capacitor+battery combinations
% 
% NT, KTH, 2022


%% figure setup 

% set latex interpreter overall by default, to fit with the '$+100\,$' etc in figure labels 
if 1
	l_ = fieldnames(get(groot,'factory'));
	for n = 1:numel(l_)
		if regexpi(l_{n},'FontSize$')
			set(groot,regexprep(l_{n},'^factory','default'),13);
		end
		if regexpi(l_{n},'Interpreter')
			set(groot,regexprep(l_{n},'^factory','default'),'Latex');
		end
	end
end

%% input data 

% a particular format of m-file is expected to be run to set the variables:
%  structure array 'd',  cell array 'l',  string 'groupname'
clear d;
%eval( 'plotdata_0_normkond' ); 
%eval( 'plotdata_1_cap_2200pF' ); 
%eval( 'plotdata_2_cap_2200pF_res820k' );
%eval( 'plotdata_3_cap_220nF_10V' );
%eval( 'plotdata_4_caphv_100pF' );
eval( 'data_5_cap66uF_batteis' );  l=lfull;


%% plotting 

% each row of 'l' is a particular case such as alkaline battery in positive
% direction; 
% the one or more datasets are listed by number in the first column of 'l';
% we join all for a particular case together into single vectors of frequency
% and real/-imag capacitance 

figure(1);

for n=1:size(l,1),
    f = [];  cp = [];  cs = [];
    for m=l{n,1}
        % add repeat sweeps to a single group;
        % the interposed 'NaN' prevents lines between data points in plots
        % from showing between points from different sweeps 
        f = [ f; NaN; d(m).d(:,1) ];
        cp = [ cp; NaN; d(m).d(:,2) ];
        cs = [ cs; NaN; d(m).d(:,3) ];
    end
    %
    subplot(2,1,1);
    if n==1, hold off;
    else hold on;
    end
    semilogx( f, cp, ['-',l{n,3}] );
    %
    subplot(2,1,2);
    if n==1, hold off;
    else hold on;
    end
    loglog( f, cs, ['-',l{n,3}] );
    %semilogx( f, cs./f, ['-',l{n,3}] ); warning('change the axis label!');
end
%
subplot(2,1,1);
legend(l{:,2});
xlabel('$f \,/\, \mathrm{Hz}$');
ylabel('$C'' \,/\,\mathrm{F}$');
set(gca,'xtick',10.^(-2:4));
set(gca,'xlim',[0.8e-2, 1.1e4]);
%
subplot(2,1,2);
legend(l{:,2});
xlabel('$f \,/\, \mathrm{Hz}$');
ylabel('$C'''' \,/\,\mathrm{F}$');
set(gca,'xtick',10.^(-2:4));
set(gca,'xlim',[0.8e-2, 1.1e4]);
%grid on


%% case-specific fine-tuning 

%subplot(2,1,2); set(gca,'ylim',[2e-13,1.1e-11], 'ytick',[1e-12,1e-11])
%subplot(2,1,1); set(gca,'ylim',[1.004,1.011]*1e-10) 
%subplot(2,1,2); set(gca,'ytick',10.^[-15:-12],'ylim',10.^[-15,-12])
%set(gca,'xtick',1e4,'xticklabel',{'10 kHz'}, 'ytick',[10,20]*1e-15,'yticklabel',{'10\,fF','20\,fF'},'FontSize',11) 



%% save output 

outname = ['fig_',groupname];
if exist([outname,'.fig'],'file')
    warning('output "%s" exists: skipping all outputs',outname);
else
    saveas(gcf,[outname,'.fig'],'fig');
    print([outname,'.png'], '-dpng');
    print([outname,'.eps'], '-depsc2');
    eval( sprintf('unix(''env -u LD_LIBRARY_PATH  epstopdf %s.eps %s.pdf'');',outname,outname) );
    % alternatively, use 'pdf' output option for 'print' .. but it seems
    % to include extra white space around the graphics
end
