%
% Intended for plotting of results from short-circuiting packs of
% 11 series-connected PP3-size 9V batteries, of two types
%
% Calculated "Rnaive" is a simple view of "internal resistance"
% based on the biggest changes in current and voltage between the
% open and short situations, which is pretty much the value one would
% get from a ~0.1s short-circuit [current declines second by second]
% Note that the resistance and [negative]reactance found from 'EIS'
% tests at varied frequency give very different results.  From these
% short-circuit tests one might think the two battery types were largely
% similar, but the other results show significant difference, e.g. at
% 0.05 Hz.


l = dir('scope*.csv');  % input files
N = numel(l);

for n=1:N,
    
    fn = l(n).name;  % filename
    x = dlmread(fn,',',4,0);
    
    t = x(:,1);  % [s]
    ch1 = x(:,2); % battery voltage via x10probe
    ch2 = x(:,3); % battery current via 100mV/A clamp
    
    v = ch1*10;
    i = ch2*10;
    
    vs = sort(v);
    dv = mean(vs(end-50:end-20)) - mean(vs(20:50));
    is = sort(i);
    di = mean(is(end-50:end-20)) - mean(is(20:50));
    Rnaive = dv/di;
    
    fct = factor(N);
    if numel(fct)==2,
        nr=min(fct);
        nc=max(fct);
    else
        nr = ceil(sqrt(N));
        nc = nr;
    end   % could be mightily improved, and better probably already exists!
    figure(2);
    subplot(nr,nc,n);
    plot( t, v/10, 'b.-', t, i, 'r.-' );
    xlabel('$t$/s');
    legend({'$v(t)$\,/\,10\,V','$i(t)$\,/\,A'},'location','best');
    %title(fn,'interpreter','none');
    title( sprintf( '\\texttt{%s}\\,: $R_\\mathrm{naive} = %.2f\\,\\Omega$', ...
        strrep(fn,'_','\_'), Rnaive ), ...
        'interpreter','latex' );
    
end


%%
if 0
    outname = 'sc_all_timeplots_and_R_estimate';
    saveas(gcf,[outname,'.fig']);
    print([outname,'.png'],'-dpng');
    print([outname,'.eps'],'-depsc2');
    eval( sprintf('unix(''env -u LD_LIBRARY_PATH  epstopdf %s.eps %s.pdf'');',outname,outname) );
end
